@@ -5,7 +5,6 @@ from gql.transport.requests import RequestsHTTPTransport
 import urllib3; urllib3.disable_warnings(urllib3.exceptions.InsecureRequestWarning)
 import pandas as pd
 from polity import static
-from polity import schemas
 from polity.static import (
     DATASET_NAME_DESC_QUERY,
     COMPANY_CIK_NAME_QUERY,
@@ -13,7 +12,8 @@ from polity.static import (
     DATASET_QUERY,
     COMPANY_QUERY,
     API_URL,
-    EQUITIES_PUBLIC_API_KEY       
+    EQUITIES_PUBLIC_API_KEY,
+    COMPANY_SCHEMA    
 )
 
 class Client():
@@ -82,7 +82,7 @@ class Client():
             if data['balance']: data['balance'] = to_df(data['balance']) 
             if data['cash']: data['cash'] = to_df(data['cash'])
             if data['equity']: data['equity'] = to_df(data['equity'])
-        return schemas.company(data)
+        return COMPANY_SCHEMA(data)
 
     def companies(self):
         static.companies()
